<?php

class CTCoreTGMPAUpdater {

    private $plugins;

    public function __construct() {

        if ( class_exists("TGM_Plugin_Activation") && has_action("tgmpa_register") ) {
            add_filter( 'plugins_api', [ $this, 'info' ], 20, 3 );
            add_filter( 'site_transient_update_plugins', [ $this, 'update' ] );
        }

    }

    public function plugins() {
        $cached_plugins = get_transient('tgmpa_plugins');
        if ($cached_plugins !== false) {
            return $cached_plugins;
        }

        do_action("tgmpa_register");
        $tgmpa = \TGM_Plugin_Activation::get_instance();
        $tgmpa->populate_file_path();

        if (empty($tgmpa->plugins)) {
            return [];
        }
        foreach ($tgmpa->plugins as $key => $plugin) {
            if ($plugin["source_type"] != "external") {
                unset($tgmpa->plugins[$key]);
            }
        }

        set_transient('tgmpa_plugins', $tgmpa->plugins, 12 * HOUR_IN_SECONDS);
        return $tgmpa->plugins;
    }

    public function get_plugins() {
        if (is_null($this->plugins)) {
            $this->plugins = $this->plugins();
        }
        return $this->plugins;
    }

    public function info( $response, $action, $args ) {

        // do nothing if you're not getting plugin information right now
        if ( 'plugin_information' !== $action || empty( $response ) ) {
            return $response;
        }

        // get updates
        $plugins = $this->get_plugins();

        if ( empty( $plugins ) ) {
            return $response;
        }

        // do nothing if plugin not in TGM Plugin Activation
        if ( empty( $args->slug ) || ! in_array( $args->slug, array_keys( $plugins ) ) ) {
            return $response;
        }

        $response->version        = $plugins[ $args->slug ]["version"];
        $response->download_link  = $plugins[ $args->slug ]["source"];
        $response->trunk          = $plugins[ $args->slug ]["source"];

        return $response;

    }

    public function update( $transient ) {

        if ( empty( $transient->checked ) ) {
            return $transient;
        }

        $plugins                      = $this->get_plugins();
        $installed_plugins            = get_plugins();
        $installed_plugins_file_paths = array_keys( $installed_plugins );

        foreach( $plugins as $plugin ) {

            $plugin                = (object) $plugin;

            // Skip if TGMPA plugin not installed
            if ( ! in_array( $plugin->file_path, $installed_plugins_file_paths ) ) {
                continue;
            }

            $response              = new \stdClass();
            $response->slug        = $plugin->slug;
            $response->plugin      = $plugin->file_path;
            $response->new_version = $plugin->version;
            $response->package     = $plugin->source;

            if ( version_compare( $installed_plugins[ $plugin->file_path ]["Version"], $plugin->version, '<' ) ) {
                $transient->response[ $plugin->file_path ] = $response;
            }
        }

        return $transient;

    }

}

$tgmpa_updater = new CTCoreTGMPAUpdater();
add_action( 'wp_loaded', [ $tgmpa_updater, '__construct' ] );

?>